@@ -36,7 +36,6 @@ from .helper import user_name_for
 from .ui_info import UIInfo
 
 from traits.api import HasPrivateTraits, HasTraits, Instance
-import collections
 
 #-------------------------------------------------------------------------------
 #  Closes a DockControl (if allowed by the associated traits UI Handler):
@@ -307,7 +306,7 @@ class Handler ( HasPrivateTraits ):
             if result is not None:
                 return result
             method = getattr( self, 'trait_view_for_%s' % name, None )
-            if isinstance( method, collections.Callable):
+            if callable( method ):
                 result = method( info, object )
                 if result is not None:
                     return result
