@@ -34,7 +34,6 @@ from traitsui.ui_traits import SequenceTypes, Image
 
 from .editor import Editor
 from .table_model import TableModel, SortFilterTableModel
-import collections
 
 #-------------------------------------------------------------------------------
 #  'TableEditor' class:
@@ -518,7 +517,7 @@ class TableEditor(Editor, BaseTableEditor):
             self.filtered_indices = list(range(num_items))
             self.filter_summary = 'All %i items' % num_items
         else:
-            if not isinstance(f, collections.Callable):
+            if not callable(f):
                 f = f.filter
             self._filtered_cache = fc = [ f(item) for item in items ]
             self.filtered_indices = fi = [ i for i, ok in enumerate(fc) if ok ]
