@@ -47,7 +47,6 @@ from .ui_info import UIInfo
 from .item import Item
 
 from .group import Group, ShadowGroup
-import collections
 
 #-------------------------------------------------------------------------------
 #  Constants:
@@ -362,12 +361,12 @@ class UI ( HasPrivateTraits ):
             handler = context.get( 'handler' )
             if handler is not None:
                 method = getattr( handler, include.id, None )
-                if isinstance( method, collections.Callable):
+                if callable( method ):
                     result = method()
 
             if (result is None) and (object is not None):
                 method = getattr( object, include.id, None )
-                if isinstance( method, collections.Callable):
+                if callable( method ):
                     result = method()
 
         return result
@@ -757,7 +756,7 @@ class UI ( HasPrivateTraits ):
         if function is None:
             return None
 
-        if isinstance( function, collections.Callable):
+        if callable( function ):
             return function( *args, **kw_args )
 
         context = self.context.copy()
