@@ -68,7 +68,6 @@ from .table_model \
     import TableModel, TraitGridSelection
 
 from .helper import TraitsUIPanel
-import collections
 from functools import reduce
 
 #-------------------------------------------------------------------------------
@@ -1024,7 +1023,7 @@ class TableEditor ( Editor, BaseTableEditor ):
                     delete.enabled = True
 
                 deletable = self.factory.deletable
-                if delete.enabled and isinstance( deletable, collections.Callable):
+                if delete.enabled and callable( deletable ):
                     delete.enabled = reduce( lambda l, r: l and r,
                         [ deletable( item ) for item in self.selected_items ],
                         True )
