@@ -53,7 +53,6 @@ from pyface.ui.wx.grid.trait_grid_cell_adapter \
 
 from pyface.timer.api \
     import do_later
-import collections
 
 
 logger = logging.getLogger(__name__)
@@ -550,7 +549,7 @@ class TableModel ( GridModel ):
             format = formats.get( type( value ) )
             if format is not None:
                 try:
-                    if isinstance( format, collections.Callable):
+                    if callable( format ):
                         value = format( value )
                     else:
                         value = format % value
@@ -818,7 +817,7 @@ class TableModel ( GridModel ):
                 nitems = [ nitem for nitem in enumerate( items ) ]
                 self.filter_summary = 'All %s items' % len( nitems )
             else:
-                if not isinstance( filter, collections.Callable):
+                if not callable( filter ):
                     filter = filter.filter
                 nitems = [ nitem for nitem in enumerate( items )
                            if list(filter( nitem[1] )) ]
